@@ -13,15 +13,15 @@ from types import TracebackType
 from typing import Any
 from typing import Awaitable
 from typing import Callable
-from typing import cast
 from typing import Generator as TypingGenerator
-from typing import overload
 from typing import Tuple
 from typing import Type
 from typing import TypeVar
 from typing import Union
-from unittest import mock
+from typing import cast
+from typing import overload
 from unittest import TestCase
+from unittest import mock
 
 import _time_machine
 from dateutil.parser import parse as parse_datetime
@@ -217,11 +217,6 @@ coordinates_stack: list[Coordinates] = []
 uuid_generate_time_attr = "_generate_time_safe"
 uuid_generate_time_patcher = mock.patch.object(uuid, uuid_generate_time_attr, new=None)
 uuid_uuid_create_patcher = mock.patch.object(uuid, "_UuidCreate", new=None)
-# We need to cause the functions to be loaded before we try patch them out,
-# which is done by this internal function
-uuid_idempotent_load_system_functions = (
-    uuid._load_system_functions  # type: ignore[attr-defined]
-)
 
 
 class travel:
@@ -237,7 +232,11 @@ class travel:
         _time_machine.patch_if_needed()
 
         if not coordinates_stack:
-            uuid_idempotent_load_system_functions()
+            if sys.version_info < (3, 9):
+                # We need to cause the functions to be loaded before we patch
+                # them out, which is done by this internal function before:
+                # https://github.com/python/cpython/pull/19948
+                uuid._load_system_functions()
             uuid_generate_time_patcher.start()
             uuid_uuid_create_patcher.start()
 
@@ -294,24 +293,26 @@ class travel:
                 raise TypeError("Can only decorate unittest.TestCase subclasses.")
 
             # Modify the setUpClass method
-            orig_setUpClass = wrapped.setUpClass
+            orig_setUpClass = wrapped.setUpClass.__func__  # type: ignore[attr-defined]
 
             @functools.wraps(orig_setUpClass)
             def setUpClass(cls: type[TestCase]) -> None:
                 self.__enter__()
                 try:
-                    orig_setUpClass()
+                    orig_setUpClass(cls)
                 except Exception:
                     self.__exit__(*sys.exc_info())
                     raise
 
             wrapped.setUpClass = classmethod(setUpClass)  # type: ignore[assignment]
 
-            orig_tearDownClass = wrapped.tearDownClass
+            orig_tearDownClass = (
+                wrapped.tearDownClass.__func__  # type: ignore[attr-defined]
+            )
 
             @functools.wraps(orig_tearDownClass)
             def tearDownClass(cls: type[TestCase]) -> None:
-                orig_tearDownClass()
+                orig_tearDownClass(cls)
                 self.__exit__(None, None, None)
 
             wrapped.tearDownClass = classmethod(  # type: ignore[assignment]
@@ -351,7 +352,7 @@ def utcnow() -> dt.datetime:
     if not coordinates_stack:
         result: dt.datetime = _time_machine.original_utcnow()
         return result
-    return dt.datetime.utcfromtimestamp(time())
+    return dt.datetime.fromtimestamp(time(), dt.timezone.utc).replace(tzinfo=None)
 
 
 # time module
